==> box64_0.2.6+dfsg.orig.tar.xz: box64-0.2.6/src/wrapped/wrappedlibice_private.h <==
#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error meh!
#endif

//GO(IceAcceptConnection, 
//GO(IceAddConnectionWatch, 
//GO(_IceAddOpcodeMapping, 
//GO(_IceAddReplyWait, 
//GO(IceAllocScratch, 
//GO(IceAppLockConn, 
//GO(IceAppUnlockConn, 
//GO(IceAuthFileName, 
//GO(_IceCheckReplyReady, 
//GO(IceCheckShutdownNegotiation, 
//GO(IceCloseConnection, 
//GO(IceComposeNetworkIdList, 
//GO(_IceConnectionClosed, 
GO(IceConnectionNumber, iFp)
//GO(_IceConnectionOpened, 
//GO(IceConnectionStatus, 
//GO(IceConnectionString, 
//GO(_IceErrorAuthenticationFailed, 
//GO(_IceErrorAuthenticationRejected, 
//GO(_IceErrorBadLength, 
//GO(_IceErrorBadMajor, 
//GO(_IceErrorBadMinor, 
//GO(_IceErrorBadState, 
//GO(_IceErrorBadValue, 
//GO(_IceErrorMajorOpcodeDuplicate, 
//GO(_IceErrorNoAuthentication, 
//GO(_IceErrorNoVersion, 
//GO(_IceErrorProtocolDuplicate, 
//GO(_IceErrorSetupFailed, 
//GO(_IceErrorUnknownProtocol, 
//GO(IceFlush, 
//GO(IceFreeAuthFileEntry, 
//GO(_IceFreeConnection, 
//GO(IceFreeListenObjs, 
//GO(IceGenerateMagicCookie, 
//GO(IceGetAuthFileEntry, 
//GO(IceGetConnectionContext, 
//GO(IceGetInBufSize, 
//GO(IceGetListenConnectionNumber, 
//GO(IceGetListenConnectionString, 
//GO(IceGetOutBufSize, 
//GO(_IceGetPaAuthData, 
//GO(_IceGetPaValidAuthIndices, 
//GO(IceGetPeerName, 
//GO(_IceGetPeerName, 
//GO(_IceGetPoAuthData, 
//GO(_IceGetPoValidAuthIndices, 
//GO(IceInitThreads, 
//GO(IceLastReceivedSequenceNumber, 
//GO(IceLastSentSequenceNumber, 
//GO(IceListenForConnections, 
//GO(IceListenForWellKnownConnections, 
//GO(IceLockAuthFile, 
//GO(IceOpenConnection, 
//GO(_IcePaMagicCookie1Proc, 
//GO(IcePing, 
//GO(_IcePoMagicCookie1Proc, 
GO(IceProcessMessages, iFppp)
//GO(IceProtocolRevision, 
//GO(IceProtocolSetup, 
//GO(IceProtocolShutdown, 
//GO(IceProtocolVersion, 
//GO(_IceRead, 
//GO(IceReadAuthFileEntry, 
//GO(_IceReadSkip, 
//GO(IceRegisterForProtocolReply, 
//GO(IceRegisterForProtocolSetup, 
//GO(IceRelease, 
//GO(IceRemoveConnectionWatch, 
//GO(_IceSearchReplyWaits, 
//GO(IceSetErrorHandler, 
//GO(IceSetHostBasedAuthProc, 
//GO(IceSetIOErrorHandler, 
//GO(IceSetPaAuthData, 
//GO(_IceSetReplyReady, 
//GO(IceSetShutdownNegotiation, 
//GO(IceSwapping, 
//GO(_IceTransAccept, 
//GO(_IceTransBytesReadable, 
//GO(_IceTransClose, 
//GO(_IceTransCloseForCloning, 
//GO(_IceTransConnect, 
//GO(_IceTransCreateListener, 
//GO(_IceTransDisconnect, 
//GO(_IceTransFreeConnInfo, 
//GO(_IceTransGetConnectionNumber, 
//GO(_IceTransGetHostname, 
//GO(_IceTransGetMyAddr, 
//GO(_IceTransGetMyNetworkId, 
//GO(_IceTransGetPeerAddr, 
//GO(_IceTransGetPeerNetworkId, 
//GO(_IceTransIsLocal, 
//GO(_IceTransMakeAllCLTSServerListeners, 
//GO(_IceTransMakeAllCOTSServerListeners, 
//GO(_IceTransNoListen, 
//GO(_IceTransOpenCLTSClient, 
//GO(_IceTransOpenCLTSServer, 
//GO(_IceTransOpenCOTSClient, 
//GO(_IceTransOpenCOTSServer, 
//GO(_IceTransRead, 
//GO(_IceTransReadv, 
//GO(_IceTransResetListener, 
//GO(_IceTransSetOption, 
//GO(_IceTransWrite, 
//GO(_IceTransWritev, 
//GO(IceUnlockAuthFile, 
//GO(IceVendor, 
//GO(_IceWrite, 
//GO(IceWriteAuthFileEntry,

==> box64_0.3.8+dfsg.orig.tar.xz: box64-0.3.8/src/wrapped/wrappedlibice_private.h <==
#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error meh!
#endif

//GO(IceAcceptConnection, 
GOM(IceAddConnectionWatch, iFEpp)
//GO(_IceAddOpcodeMapping, 
//GO(_IceAddReplyWait, 
//GO(IceAllocScratch, 
//GO(IceAppLockConn, 
//GO(IceAppUnlockConn, 
//GO(IceAuthFileName, 
//GO(_IceCheckReplyReady, 
//GO(IceCheckShutdownNegotiation, 
//GO(IceCloseConnection, 
//GO(IceComposeNetworkIdList, 
//GO(_IceConnectionClosed, 
GO(IceConnectionNumber, iFp)
//GO(_IceConnectionOpened, 
//GO(IceConnectionStatus, 
//GO(IceConnectionString, 
//GO(_IceErrorAuthenticationFailed, 
//GO(_IceErrorAuthenticationRejected, 
//GO(_IceErrorBadLength, 
//GO(_IceErrorBadMajor, 
//GO(_IceErrorBadMinor, 
//GO(_IceErrorBadState, 
//GO(_IceErrorBadValue, 
//GO(_IceErrorMajorOpcodeDuplicate, 
//GO(_IceErrorNoAuthentication, 
//GO(_IceErrorNoVersion, 
//GO(_IceErrorProtocolDuplicate, 
//GO(_IceErrorSetupFailed, 
//GO(_IceErrorUnknownProtocol, 
//GO(IceFlush, 
//GO(IceFreeAuthFileEntry, 
//GO(_IceFreeConnection, 
//GO(IceFreeListenObjs, 
//GO(IceGenerateMagicCookie, 
//GO(IceGetAuthFileEntry, 
//GO(IceGetConnectionContext, 
//GO(IceGetInBufSize, 
//GO(IceGetListenConnectionNumber, 
//GO(IceGetListenConnectionString, 
//GO(IceGetOutBufSize, 
//GO(_IceGetPaAuthData, 
//GO(_IceGetPaValidAuthIndices, 
//GO(IceGetPeerName, 
//GO(_IceGetPeerName, 
//GO(_IceGetPoAuthData, 
//GO(_IceGetPoValidAuthIndices, 
//GO(IceInitThreads, 
//GO(IceLastReceivedSequenceNumber, 
//GO(IceLastSentSequenceNumber, 
//GO(IceListenForConnections, 
//GO(IceListenForWellKnownConnections, 
//GO(IceLockAuthFile, 
//GO(IceOpenConnection, 
//GO(_IcePaMagicCookie1Proc, 
//GO(IcePing, 
//GO(_IcePoMagicCookie1Proc, 
GO(IceProcessMessages, iFppp)
//GO(IceProtocolRevision, 
//GO(IceProtocolSetup, 
//GO(IceProtocolShutdown, 
//GO(IceProtocolVersion, 
//GO(_IceRead, 
//GO(IceReadAuthFileEntry, 
//GO(_IceReadSkip, 
//GO(IceRegisterForProtocolReply, 
//GO(IceRegisterForProtocolSetup, 
//GO(IceRelease, 
GOM(IceRemoveConnectionWatch, iFEpp)
//GO(_IceSearchReplyWaits, 
GOM(IceSetErrorHandler, pFEp)
//GO(IceSetHostBasedAuthProc, 
GOM(IceSetIOErrorHandler, pFEp)
//GO(IceSetPaAuthData, 
//GO(_IceSetReplyReady, 
//GO(IceSetShutdownNegotiation, 
//GO(IceSwapping, 
//GO(_IceTransAccept, 
//GO(_IceTransBytesReadable, 
//GO(_IceTransClose, 
//GO(_IceTransCloseForCloning, 
//GO(_IceTransConnect, 
//GO(_IceTransCreateListener, 
//GO(_IceTransDisconnect, 
//GO(_IceTransFreeConnInfo, 
//GO(_IceTransGetConnectionNumber, 
//GO(_IceTransGetHostname, 
//GO(_IceTransGetMyAddr, 
//GO(_IceTransGetMyNetworkId, 
//GO(_IceTransGetPeerAddr, 
//GO(_IceTransGetPeerNetworkId, 
//GO(_IceTransIsLocal, 
//GO(_IceTransMakeAllCLTSServerListeners, 
//GO(_IceTransMakeAllCOTSServerListeners, 
//GO(_IceTransNoListen, 
//GO(_IceTransOpenCLTSClient, 
//GO(_IceTransOpenCLTSServer, 
//GO(_IceTransOpenCOTSClient, 
//GO(_IceTransOpenCOTSServer, 
//GO(_IceTransRead, 
//GO(_IceTransReadv, 
//GO(_IceTransResetListener, 
//GO(_IceTransSetOption, 
//GO(_IceTransWrite, 
//GO(_IceTransWritev, 
//GO(IceUnlockAuthFile, 
//GO(IceVendor, 
//GO(_IceWrite, 
//GO(IceWriteAuthFileEntry,
